Package: logcondiscr
Type: Package
Title: Estimate a Log-Concave Probability Mass Function from Discrete
        I.i.d. Observations
Version: 1.0.7
Date: 2026-04-26
Authors@R: 
    c(person(given = "Kaspar", family = "Rufibach", role = c("aut", "cre"), email = "kaspar.rufibach@gmail.com"),
    person(given = "Fadoua", family = "Balabdaoui", role = "aut", email = "fadoua.balabdaoui@stat.math.ethz.ch"),
    person(given = "Hanna", family = "Jankowski", role = "aut", email = "hkj@yorku.ca"))
Maintainer: Kaspar Rufibach <kaspar.rufibach@gmail.com>
Depends: Matrix, mvtnorm, cobs
Imports: stats
Description: Given independent and identically distributed observations X(1), ..., X(n), allows to compute the maximum likelihood estimator (MLE) of probability mass function (pmf) under the assumption that it is log-concave, see Weyermann (2007) and Balabdaoui, Jankowski, Rufibach, and Pavlides (2012). The main functions of the package are 'logConDiscrMLE' that allows computation of the log-concave MLE, 'logConDiscrCI' that computes pointwise confidence bands for the MLE, and 'kInflatedLogConDiscr' that computes a mixture of a log-concave PMF and a point mass at k.
License: GPL (>= 2)
URL: http://www.kasparrufibach.ch ,
        https://people.math.ethz.ch/~fadouab/ ,
        https://www.yorku.ca/hkj/
NeedsCompilation: no
Packaged: 2026-04-26 16:30:47 UTC; kaspa
Author: Kaspar Rufibach [aut, cre],
  Fadoua Balabdaoui [aut],
  Hanna Jankowski [aut]
Repository: CRAN
Date/Publication: 2026-04-26 16:40:03 UTC
Built: R 4.5.2; ; 2026-05-01 18:02:33 UTC; unix
